@@ -149,7 +149,9 @@ pub fn eval(
 ) -> Result<Option<KalkNum>, CalcError> {
     // Variable and function declaration parsers will set this to false
     // if the equal sign is for one of those instead.
-    context.contains_equation_equal_sign = input.contains("=");
+    // It also should not contain an iverson bracket, since equal signs in there
+    // mean something else. This is not super reliable, and should probably be improved in the future.
+    context.contains_equation_equal_sign = input.contains("=") && !input.contains("[");
     let statements = parse(context, input)?;
 
     let mut interpreter = interpreter::Context::new(
@@ -302,13 +304,14 @@ fn parse_unit_decl_stmt(context: &mut Context) -> Result<Stmt, CalcError> {
 }
 
 fn parse_expr(context: &mut Context) -> Result<Expr, CalcError> {
-    Ok(parse_equation(context)?)
+    Ok(parse_equality(context)?)
 }
 
-fn parse_equation(context: &mut Context) -> Result<Expr, CalcError> {
-    let left = parse_to(context)?;
+fn parse_equality(context: &mut Context) -> Result<Expr, CalcError> {
+    let mut left = parse_to(context)?;
 
-    if match_token(context, TokenKind::Equals) {
+    // Equation
+    if match_token(context, TokenKind::Equals) && context.contains_equation_equal_sign {
         advance(context);
         let right = parse_to(context)?;
         let var_name = if let Some(var_name) = &context.equation_variable {
@@ -333,9 +336,25 @@ fn parse_equation(context: &mut Context) -> Result<Expr, CalcError> {
             Identifier::from_full_name(var_name),
             Box::new(inverted.clone()),
         ));
+
         return Ok(inverted);
     }
 
+    // Equality check
+    while match_token(context, TokenKind::Equals)
+        || match_token(context, TokenKind::NotEquals)
+        || match_token(context, TokenKind::GreaterThan)
+        || match_token(context, TokenKind::LessThan)
+        || match_token(context, TokenKind::GreaterOrEquals)
+        || match_token(context, TokenKind::LessOrEquals)
+    {
+        let op = peek(context).kind;
+        advance(context);
+        let right = parse_to(context)?;
+
+        left = Expr::Binary(Box::new(left), op, Box::new(right));
+    }
+
     Ok(left)
 }
 
@@ -390,13 +409,19 @@ fn parse_factor(context: &mut Context) -> Result<Expr, CalcError> {
         || match_token(context, TokenKind::Identifier)
         || match_token(context, TokenKind::Literal)
         || match_token(context, TokenKind::OpenParenthesis)
+        || match_token(context, TokenKind::OpenCeil)
+        || match_token(context, TokenKind::OpenFloor)
+        || match_token(context, TokenKind::OpenBracket)
     {
         // If the token is an identifier, literal, or open parenthesis,
         // assume it's multiplication. Eg. 3y or (3x + 2)(2 + 3)
         let op = match peek(context).kind {
-            TokenKind::Identifier | TokenKind::Literal | TokenKind::OpenParenthesis => {
-                TokenKind::Star
-            }
+            TokenKind::Identifier
+            | TokenKind::Literal
+            | TokenKind::OpenParenthesis
+            | TokenKind::OpenCeil
+            | TokenKind::OpenFloor
+            | TokenKind::OpenBracket => TokenKind::Star,
             _ => advance(context).kind,
         };
 
@@ -462,7 +487,9 @@ fn parse_factorial(context: &mut Context) -> Result<Expr, CalcError> {
 fn parse_primary(context: &mut Context) -> Result<Expr, CalcError> {
     let expr = match peek(context).kind {
         TokenKind::OpenParenthesis => parse_group(context)?,
-        TokenKind::Pipe | TokenKind::OpenCeil | TokenKind::OpenFloor => parse_group_fn(context)?,
+        TokenKind::Pipe | TokenKind::OpenCeil | TokenKind::OpenFloor | TokenKind::OpenBracket => {
+            parse_group_fn(context)?
+        }
         TokenKind::Identifier => parse_identifier(context)?,
         TokenKind::Literal => Expr::Literal(string_to_num(&advance(context).value)?),
         _ => return Err(CalcError::UnableToParseExpression),
@@ -484,6 +511,7 @@ fn parse_group_fn(context: &mut Context) -> Result<Expr, CalcError> {
         TokenKind::Pipe => "abs",
         TokenKind::OpenCeil => "ceil",
         TokenKind::OpenFloor => "floor",
+        TokenKind::OpenBracket => "iverson",
         _ => unreachable!(),
     };
 
@@ -504,7 +532,11 @@ fn parse_identifier(context: &mut Context) -> Result<Expr, CalcError> {
     {
         // If there is a function with this name, parse it as a function, with the next token as the argument.
         if context.symbol_table.contains_fn(&identifier.pure_name) {
-            let parameter = parse_factor(context)?;
+            let parameter = if identifier.full_name == "√" {
+                parse_exponent(context)?
+            } else {
+                parse_factor(context)?
+            };
             return Ok(Expr::FnCall(identifier, vec![parameter]));
         }
     }
@@ -546,7 +578,7 @@ fn parse_identifier(context: &mut Context) -> Result<Expr, CalcError> {
 
     // Eg. x
     if parse_as_var_instead || context.symbol_table.contains_var(&identifier.pure_name) {
-        Ok(Expr::Var(identifier))
+        Ok(build_var(context, &identifier.full_name))
     } else if context.parsing_unit_decl {
         context.unit_decl_base_unit = Some(identifier.full_name);
         Ok(Expr::Var(Identifier::from_full_name(DECL_UNIT)))
